==> ose-metering-ansible-operator-container-v4.3.9-202003230345.tar.gz: ose-metering-ansible-operator-container-v4.3.9-202003230345/test/reportingframework/service.go <==
package reportingframework

import (
	"bytes"
	"fmt"
	"io/ioutil"
	"net/http"
	"net/url"
	"path"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"

	"k8s.io/apimachinery/pkg/util/net"
)

const (
	reportingOperatorServiceName     = "reporting-operator"
	reportingOperatorServicePortName = "http"
	meteringRouteName                = "metering"
)

func (rf *ReportingFramework) doRequest(endpoint, method string, body []byte, query map[string]string) (respBody []byte, code int, err error) {
	var u *url.URL

	if rf.UseRouteForReportingAPI {
		const routeName = "metering"

		// query all routes for the metering route
		meteringRoute, err := rf.RouteClient.Routes(rf.Namespace).Get(meteringRouteName, metav1.GetOptions{})
		if err != nil {
			return nil, 0, fmt.Errorf("query for metering route failed, err: %v", err)
		}

		u = &url.URL{
			Scheme: "https",
			Host:   meteringRoute.Spec.Host,
			Path:   endpoint,
		}
	} else if rf.UseKubeProxyForReportingAPI {
		u = rf.KubeAPIURL
		proto := "http"
		if rf.HTTPSAPI {
			proto = "https"
		}
		apiProxyPath := fmt.Sprintf("/api/v1/namespaces/%s/services/%s/proxy/", rf.Namespace, net.JoinSchemeNamePort(proto, reportingOperatorServiceName, reportingOperatorServicePortName))
		u.Path = path.Join(apiProxyPath, endpoint)
	} else {
		u = rf.ReportingAPIURL
		if rf.HTTPSAPI {
			u.Scheme = "https"
		}
		u.Path = endpoint
	}

	req := &http.Request{
		URL:    u,
		Method: method,
		Header: make(http.Header),
	}

	if rf.UseRouteForReportingAPI {
		// check if the bearer token to the reporting-operator serviceaccount is uninitialized
		if rf.RouteBearerToken == "" {
			return nil, 0, fmt.Errorf("use-route-for-reporting-api is set to true, but route-bearer-token is uninitialized: %v", err)
		}

		accessToken := "Bearer " + rf.RouteBearerToken
		req.Header.Set("Authorization", accessToken)
	}

	if body != nil {
		req.Body = ioutil.NopCloser(bytes.NewReader(body))
	}

	q := req.URL.Query()
	for key, val := range query {
		q.Set(key, val)
	}
	req.URL.RawQuery = q.Encode()

	resp, err := rf.HTTPClient.Do(req)
	if err != nil {
		return nil, 0, err
	}
	defer resp.Body.Close()

	respBody, err = ioutil.ReadAll(resp.Body)
	if err != nil {
		return nil, resp.StatusCode, err
	}

	return respBody, resp.StatusCode, nil
}

func (rf *ReportingFramework) ReportingOperatorRequest(endpoint string, query map[string]string) (respBody []byte, code int, err error) {
	return rf.doRequest(endpoint, "GET", nil, query)
}

func (rf *ReportingFramework) ReportingOperatorPOSTRequest(endpoint string, body []byte) (respBody []byte, code int, err error) {
	return rf.doRequest(endpoint, "POST", body, nil)
}

==> ose-metering-ansible-operator-container-v4.6.0-202104261627.p0.tar.gz: ose-metering-ansible-operator-container-v4.6.0-202104261627.p0/test/reportingframework/service.go <==
package reportingframework

import (
	"bytes"
	"context"
	"fmt"
	"io/ioutil"
	"net/http"
	"net/url"
	"path"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"

	"k8s.io/apimachinery/pkg/util/net"
)

const (
	reportingOperatorServiceName     = "reporting-operator"
	reportingOperatorServicePortName = "http"
	meteringRouteName                = "metering"
)

func (rf *ReportingFramework) determineMeteringAPIUrl(endpoint string) (*url.URL, error) {
	u := rf.ReportingAPIURL

	if rf.UseRouteForReportingAPI {
		meteringRoute, err := rf.RouteClient.Routes(rf.Namespace).Get(context.Background(), meteringRouteName, metav1.GetOptions{})
		if err != nil {
			return nil, err
		}

		return &url.URL{
			Scheme: "https",
			Host:   meteringRoute.Spec.Host,
			Path:   endpoint,
		}, nil
	}
	if rf.UseKubeProxyForReportingAPI {
		u = rf.KubeAPIURL
		scheme := "http"

		if rf.HTTPSAPI {
			scheme = "https"
		}
		apiProxyPath := fmt.Sprintf("/api/v1/namespaces/%s/services/%s/proxy/", rf.Namespace, net.JoinSchemeNamePort(scheme, reportingOperatorServiceName, reportingOperatorServicePortName))
		u.Path = path.Join(apiProxyPath, endpoint)
		return u, nil
	}
	if rf.HTTPSAPI {
		u.Scheme = "https"
	}
	u.Path = endpoint

	return u, nil
}

func (rf *ReportingFramework) doRequest(endpoint, method string, body []byte, query map[string]string) (respBody []byte, code int, err error) {
	u, err := rf.determineMeteringAPIUrl(endpoint)
	if err != nil {
		return nil, 0, fmt.Errorf("failed to successfully return an initialized url.URL object: %v", err)
	}

	req := &http.Request{
		URL:    u,
		Method: method,
		Header: make(http.Header),
	}

	if rf.UseRouteForReportingAPI {
		// check if the bearer token to the reporting-operator serviceaccount is uninitialized
		if rf.RouteBearerToken == "" {
			return nil, 0, fmt.Errorf("use-route-for-reporting-api is set to true, but route-bearer-token is uninitialized: %v", err)
		}

		accessToken := "Bearer " + rf.RouteBearerToken
		req.Header.Set("Authorization", accessToken)
	}

	if body != nil {
		req.Body = ioutil.NopCloser(bytes.NewReader(body))
	}

	q := req.URL.Query()
	for key, val := range query {
		q.Set(key, val)
	}
	req.URL.RawQuery = q.Encode()

	resp, err := rf.HTTPClient.Do(req)
	if err != nil {
		return nil, 0, err
	}
	defer resp.Body.Close()

	respBody, err = ioutil.ReadAll(resp.Body)
	if err != nil {
		return nil, resp.StatusCode, err
	}

	return respBody, resp.StatusCode, nil
}

// ReportingOperatorGetRequest is a reportingframework method that performs
// a single GET request to the metering API.
func (rf *ReportingFramework) ReportingOperatorGetRequest(endpoint string, query map[string]string) (respBody []byte, code int, err error) {
	return rf.doRequest(endpoint, "GET", nil, query)
}

// ReportingOperatorPOSTRequest is a reportingframework method that performs
// a single POST request to the metering API.
func (rf *ReportingFramework) ReportingOperatorPOSTRequest(endpoint string, body []byte) (respBody []byte, code int, err error) {
	return rf.doRequest(endpoint, "POST", body, nil)
}
